@@ -10,7 +10,7 @@ use Moo;
 
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 sub transform_source {
     my ( $self, $source ) = @_;
@@ -29,6 +29,14 @@ sub transform_source {
     # might be hidden in other bundles, e.g. -pbp.  Be defensive and
     # check both.
     my ( $output, $error_flag, $errorfile, $stderr, $destination );
+
+    # Add --encode-output-strings (-eos) for PT releases in 2022 and later to
+    # tell perltidy that we want encoded character strings returned.  See
+    # https://github.com/houseabsolute/perl-code-tidyall/issues/84
+    # https://github.com/perltidy/perltidy/issues/83
+    my $argv = $self->argv;
+    $argv .= ' --encode-output-strings' if $Perl::Tidy::VERSION > 20220101;
+
     $output = capture_merged {
         $error_flag = Perl::Tidy::perltidy(
             argv        => $self->argv,
@@ -61,7 +69,7 @@ Code::TidyAll::Plugin::PerlTidy - Use perltidy with tidyall
 
 =head1 VERSION
 
-version 0.80
+version 0.81
 
 =head1 SYNOPSIS
 
@@ -97,6 +105,11 @@ This plugin accepts the following configuration options:
 
 Arguments to pass to C<perltidy>.
 
+If you are using C<Perl::Tidy> version 20220101 or newer, than the
+C<--encode-output-strings> flag will be appended to whatever you supply. In
+this case, you should ensure that you are I<not> passing a
+C<--character-encoding> (C<-enc>) or C<-utf8> flag to perltidy as well.
+
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
@@ -121,7 +134,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2021 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2022 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
